==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/ReplicationRuleAndOperator.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Prefix
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ReplicationRuleAndOperator(
    prefix: Optional[Prefix] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.s3.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator = {
    import ReplicationRuleAndOperator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
      .builder()
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly =
    zio.aws.s3.model.ReplicationRuleAndOperator.wrap(buildAwsValue())
}
object ReplicationRuleAndOperator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationRuleAndOperator =
      zio.aws.s3.model.ReplicationRuleAndOperator(
        prefix.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def prefix: Optional[Prefix]
    def tags: Optional[List[zio.aws.s3.model.Tag.ReadOnly]]
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getTags: ZIO[Any, AwsError, List[zio.aws.s3.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ) extends zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly {
    override val prefix: Optional[Prefix] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.s3.model.primitives.Prefix(value))
    override val tags: Optional[List[zio.aws.s3.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.s3.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ): zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/ReplicationRuleAndOperator.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.Prefix
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ReplicationRuleAndOperator(
    prefix: Option[Prefix] = None,
    tags: Option[Iterable[zio.aws.s3.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator = {
    import ReplicationRuleAndOperator.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
      .builder()
      .optionallyWith(
        prefix.map(value => Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly =
    zio.aws.s3.model.ReplicationRuleAndOperator.wrap(buildAwsValue())
}
object ReplicationRuleAndOperator {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationRuleAndOperator =
      zio.aws.s3.model.ReplicationRuleAndOperator(
        prefix.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def prefix: Option[Prefix]
    def tags: Option[List[zio.aws.s3.model.Tag.ReadOnly]]
    def getPrefix: ZIO[Any, AwsError, Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getTags: ZIO[Any, AwsError, List[zio.aws.s3.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ) extends zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly {
    override val prefix: Option[Prefix] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.s3.model.primitives.Prefix(value))
    override val tags: Option[List[zio.aws.s3.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.s3.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationRuleAndOperator
  ): zio.aws.s3.model.ReplicationRuleAndOperator.ReadOnly = new Wrapper(impl)
}
